3D Graphics
===========

.. toctree::
   :maxdepth: 1

   sage/plot/plot3d/introduction

Function and Data Plots
-----------------------

.. toctree::
   :maxdepth: 1

   sage/plot/plot3d/plot3d
   sage/plot/plot3d/parametric_plot3d
   sage/plot/plot3d/revolution_plot3d
   sage/plot/plot3d/plot_field3d
   sage/plot/plot3d/implicit_plot3d
   sage/plot/plot3d/list_plot3d


Basic Shapes and Primitives
---------------------------

.. toctree::
   :maxdepth: 1

   sage/plot/plot3d/base
   sage/plot/plot3d/shapes
   sage/plot/plot3d/shapes2
   sage/plot/plot3d/platonic
   sage/plot/plot3d/parametric_surface
   sage/plot/plot3d/implicit_surface

Infrastructure
--------------

.. toctree::
   :maxdepth: 1

   sage/plot/plot3d/texture
   sage/plot/plot3d/index_face_set
   sage/plot/plot3d/transform
   sage/plot/plot3d/tri_plot

Backends
--------

.. toctree::
   :maxdepth: 1

   sage/plot/plot3d/tachyon
   threejs

.. include:: ../footer.txt
